@@ -10,12 +10,14 @@ import typing_extensions
 
 import aws_cdk._jsii
 import constructs._jsii
+import pepperize_cdk_private_bucket._jsii
+import pepperize_cdk_security_group._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@pepperize/cdk-autoscaling-gitlab-runner",
-    "0.0.175",
+    "0.1.0",
     __name__[0:-6],
-    "cdk-autoscaling-gitlab-runner@0.0.175.jsii.tgz",
+    "cdk-autoscaling-gitlab-runner@0.1.0.jsii.tgz",
 )
 
 __all__ = [
